@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 1326 2022-04-25 11:56:17Z Jacky $
+# $Id: __init__.py 1334 2022-05-02 09:45:40Z Jacky $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Jacky $ (last)
-# $Date: 2022-04-25 19:56:17 +0800 (週一, 25 四月 2022) $
-# $Revision: 1326 $
+# $Date: 2022-05-02 17:45:40 +0800 (週一, 02 五月 2022) $
+# $Revision: 1334 $
 
 import os
 import sys
@@ -412,14 +412,14 @@ def grepData(filePath, pattern, encoding='UTF-8'):
     @param encoding: The file's encoding method.
     @return: String after the pattern if the file exists and the file contains the pattern. Otherwise, None.
     """
-    try:
-        with open(filePath, 'r', encoding=encoding) as f:
-            for line in f.readlines():
-                if line.startswith(pattern):
-                    return line[len(pattern):].strip()
-            return None
-    except:
+    if not Path(filePath).exists():
         return None
+    with open(filePath, 'r', encoding=encoding) as f:
+        for line in f.readlines():
+            if line.startswith(pattern):
+                return line[len(pattern):].strip()
+            return None
+    return None
 
 def getRepository(projectPath):
     """
@@ -432,3 +432,18 @@ def getRepository(projectPath):
     repository = grepData('info.txt', 'URL: ', encoding=None)
     os.remove('info.txt')
     return repository
+
+def validateDomainFormat(domain):
+    """
+    Check if the domain name is in valid format.
+    Only lowercase characters, numbers, "-" and "." are valid in domain name. 
+
+    @param domain: The domain name.
+    @return: A boolean. The domain name is in valid format or not.
+    """
+    # Using regex: re.match()
+    # If match, the function returns a "re.Match" object,
+    # which can be converted to a boolean type object with "True" value.
+    # Else, returns "None".
+    pattern = r'([a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]'
+    return bool(re.match(pattern, domain))
